@@ -1,9 +1,16 @@
-require 'pathname'
 require 'rubygems'
 
-SPEC_ROOT = Pathname(__FILE__).dirname.expand_path
-require SPEC_ROOT.parent + 'lib/dm-aggregates'
-Pathname.glob((SPEC_ROOT + '{lib,*/shared}/**/*.rb').to_s).each { |f| require f }
+# use local dm-core if running from a typical dev checkout.
+lib = File.join('..', '..', 'dm-core', 'lib')
+$LOAD_PATH.unshift(lib) if File.directory?(lib)
+require 'dm-core'
+
+# Support running specs with 'rake spec' and 'spec'
+$LOAD_PATH.unshift('lib') unless $LOAD_PATH.include?('lib')
+
+require 'dm-aggregates'
+
+require 'public/shared/aggregate_shared_spec'
 
 def load_driver(name, default_uri)
   return false if ENV['ADAPTER'] != name.to_s
