@@ -1,6 +1,4 @@
 begin
-  gem 'rspec', '~>1.1.11'
-  require 'spec'
   require 'spec/rake/spectask'
 
   task :default => [ :spec ]
@@ -8,16 +6,18 @@ begin
   desc 'Run specifications'
   Spec::Rake::SpecTask.new(:spec) do |t|
     t.spec_opts << '--options' << 'spec/spec.opts' if File.exists?('spec/spec.opts')
-    t.spec_files = Pathname.glob((ROOT + 'spec/**/*_spec.rb').to_s).map { |f| f.to_s }
+    t.libs      << 'lib' << 'spec' # needed for CI rake spec task, duplicated in spec_helper
 
     begin
-      gem 'rcov', '~>0.8'
+      require 'rcov'
       t.rcov = JRUBY ? false : (ENV.has_key?('NO_RCOV') ? ENV['NO_RCOV'] != 'true' : true)
       t.rcov_opts << '--exclude' << 'spec'
       t.rcov_opts << '--text-summary'
       t.rcov_opts << '--sort' << 'coverage' << '--sort-reverse'
     rescue LoadError
       # rcov not installed
+    rescue SyntaxError
+      # rcov syntax invalid
     end
   end
 rescue LoadError
